<?php
require('./tools/seqtools.php');// include sequence functions, parsing etc.
require('./tools/formtools.php');
require('./tools/reporttools.php');

// Form buttons from main form
$submit = $_POST['submit'];
$submit_example = $_POST['submit_example'];
$filename=$_POST['filename'];

function parse_sequences ($inputseqs) {
  $sequences = parse_fasta($inputseqs, 0, "-"); // returns array of sequences, each consist of two elements: header and sequence, i.e. $var[0][0] = header of seq 1, $var[0][1] = sequence 1 etc...
  if (count($sequences) ==0){
    $error = "Couldn't parse FASTA input correctly, please submit fasta formatted sequences";
    return array(1,$error);
  }
  return array(0,$sequences);
}

function get_mrbayes($haplotypes, $fn="mrbayes.nex") {
  $numberofhaplotypes=count($haplotypes);
  $len=strlen($haplotypes[0][1]); // getting length of first sequence
  $gc="-";
  $mrbayes= "#NEXUS\n";
  foreach ($haplotypes as $current){
    $mrbayes .="[Sequence: ".$current[0]."\tLength:\t:".strlen($current[1])."]\n";
  }
  $mrbayes.=<<<BAY

BEGIN DATA;
\tDIMENSIONS NTAX={$numberofhaplotypes} NCHAR={$len};
\tFORMAT DATATYPE=DNA INTERLEAVE=NO GAP={$gc};
BAY;
 $mrbayes.="\n\tMATRIX\n";
 foreach ($haplotypes as $current){
   $mrbayes .="\t".safeheader($current[0])."\t".$current[1]."\n";
 }
 $mrbayes.="\n;\nend;\n";

 $mrbayes .= <<<BAY

begin mrbayes;
\t set autoclose=yes;
\t set nowarn=yes;
\t [! No molecular clock --------------------------------------- ]
\t lset nst=6 rates=gamma;
\t prset brlenspr=unconstrained:Exp(10.0);
\t mcmc nruns=1 ngen=1000000 samplefreq=1000 file=$fn.noclock.mb;
\t sump burnin=250;
\t sumt burnin=250;
\t [! Uniform molecular clock ---------------------------------- ]
\t prset brlenspr=clock:uniform;
\t prset treeheightpr=Exp(1.0);
\t mcmc nruns=1 ngen=1000000 samplefreq=1000 file=$fn.clock.mb;
\t sump burnin=250;
\t sumt burnin=250;
\t [! Coalescence molecular clock, run 1 ----------------------- ]
\t prset brlenspr=clock:coalescence;
\t mcmc nruns=1 ngen=2000000 samplefreq=1000 file=$fn.coalesence1.mb;
\t sump burnin=500;
\t sumt burnin=500;
\t [! Coalescence molecular clock, run 2 ----------------------- ]
\t prset brlenspr=clock:coalescence;
\t mcmc nruns=1 ngen=2000000 samplefreq=1000 file=$fn.coalesence2.mb;
\t sump burnin=500;
\t sumt burnin=500;
\t [! Coalescence molecular clock, run 3 ----------------------- ]
\t prset brlenspr=clock:coalescence;
\t mcmc nruns=1 ngen=2000000 samplefreq=1000 file=$fn.coalesence3.mb;
\t sump burnin=500;
\t sumt burnin=500;
\t quit;
end;
BAY;

  $r['text'] = $mrbayes;
  $r['textlabel']="MrBayes input file";

  $r['html'] = "<PRE>$mrbayes</PRE>\n";
  $r['htmllabel']="MrBayes input file";

  $r['filename']= "$fn";
  $r['filelabel']="Save MrBayes input file";
 return $r;
}


if ($submit) {
  $r= parse_sequences($inputseqs);
  if ($r[0]=="0") {
    $sequences=$r[1];
    $mb= get_mrbayes($sequences, $filename);
  } else {
    $error = $r[1];
    $r='';
  }
  unset($r);
}
//
// BEGIN HTML OUTPUT!
//
show_page_header("Fasta to MrBayes converter", "<a href='#results'>Conversion finished, results are at bottom (or click here)</a>", $submit, $error);
?>
<!-- INPUT FORM -->
<form action="#" method='POST' enctype='multipart/form-data'>
<?php
show_fieldset_inputseqs ($submit_example, $inputseqs, "./examples/fasta2mrbayes.fa") 
?>
<P>
<!-- Settings fieldset -->
<fieldset>
<legend>Settings</legend>
<P>
<label>(Optional) custom output filename</label> <input type="text" name ="filename" size=15 value="<?php if($filename) {echo $filename; } else {echo 'mrbayes.nex';}?>"/>
</p>
<?php
show_submit_buttons("Do formatting");
?>
</fieldset>
</form>

<!-- RESULTS SECTION  -->

<?php
   if ($error) {
     print "<h1><font color ='#AA0000'><br> $error</font></h1>\n";
   }
 
  if ($submit and !$error) {
    print "<a name='results'>";
    $b[] = get_save_button($mb, 'r1');
    print get_save_form($b, "Save MrBayes input file");
    print get_results_from_buttons($b);
}

//
// END HTML OUTPUT
//

?>
<?php
show_page_footer();
?>
