<?php
function parse_fasta($input, $removegaps=0, $gapchar='-'){
  if (preg_match("/\r\n/i", $input)) {
      // Conditionally convert DOS to Unix \r\n --> \n
	  $input=str_replace("\r\n","\n",$input);
	} 
  elseif (preg_match("/\r/i", $input)) {
		// Conditionally convert MAX to Unix \r --> \n
  	$input=str_replace("\r","\n",$input);
	}
  // Remove comment lines
 $input2= "";
  foreach (explode("\n",$input) as $line) {
    if (strpos($line, "#")!== 0) {
      $input2 .= $line."\n";
    }
  }
$sequences         = explode(">", $input2);
array_shift($sequences); // loose first empty sequence
$numberofsequences = count($sequences);

for ($i=0; $i<$numberofsequences; $i++) {
  $sequences[$i]    = explode("\n",$sequences[$i], 2);// explode single sequence into 2 elements
  $sequences[$i][0] = chop($sequences[$i][0]);// remove newline from header
  $sequences[$i][1] = preg_replace('/\s/','',strtoupper( $sequences[$i][1]) );// remove space and newlines from sequence data
  if ($removegaps == 1) {
    $sequences[$i][1] = preg_replace("/$gapchar/",'',$sequences[$i][1]);// remove gapchar from sequence data
  }   
}
return $sequences;
}

function wrap_sequence($promotorsequence, $wrapwidth, $wrapchar) {
  $promotorlength = strlen($promotorsequence);
  $promotorwrapped ='';
  for ($j = 0; $j < $promotorlength; ($j=$j+$wrapwidth)) {
    $promotorpart = substr($promotorsequence,$j,$wrapwidth);
    $promotorwrapped .= $promotorpart . $wrapchar;
  }
  return $promotorwrapped;
}

function safeheader($header) {
  $header=str_replace("|","_",$header);
  $header=str_replace("-","_",$header);
  $header=str_replace(":","_",$header);
  $header=str_replace(";","_",$header);
  $header=str_replace("(","_",$header);
  $header=str_replace(")","_",$header);
  $header=str_replace("[","_",$header);
  $header=str_replace("]","_",$header);
  $header=str_replace(" ","_",$header);
  return $header;
}

function sequences2fasta($seqs, $wrap=60) {
  $fullset ="";
  for ($i=0; $i<count($seqs); $i++) {// all sequences
    $current=$seqs[$i];
    $fullset .= ">".$current[0]."\n";
    $fullset .= wrap_sequence($current[1], $wrap, "\n");
    $fullset .= "\n";
  }
  return $fullset;
}


?>
